@@ -10,7 +10,7 @@ use Capture::Tiny qw(capture);
 use File::Temp qw(tempfile);
 use Proc::ChildError qw(explain_child_error);
 
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 our %SPEC;
 
@@ -18,8 +18,23 @@ sub _check_patch_has_dry_run_option {
     # some versions of the 'patch' program, like that on freebsd, does not
     # support the needed --dry-run option. we currently can't run on those
     # systems.
-    my (undef, undef, $exit) = capture { system "patch --dry-run -v" };
-    return $exit == 0;
+
+    # this currently doesn't work on openbsd, since openbsd's patch does not
+    # exit non-zero if fed unknown options.
+    #my (undef, undef, $exit) = capture { system "patch --dry-run -v" };
+    #return $exit == 0;
+
+    # cache result
+    state $res = do {
+        # hm, what about windows?
+        #my $man = qx(man patch);
+        #$man =~ /--dry-run/;
+
+        my $help = qx(patch --help);
+        $help =~ /--dry-run/;
+    };
+
+    $res;
 }
 
 $SPEC{patch} = {
@@ -162,7 +177,7 @@ File::Patch::Undoable - Patch a file, with undo support
 
 =head1 VERSION
 
-This document describes version 0.03 of File::Patch::Undoable (from Perl distribution File-Patch-Undoable), released on 2014-05-17.
+This document describes version 0.04 of File::Patch::Undoable (from Perl distribution File-Patch-Undoable), released on 2014-05-28.
 
 =head1 FUNCTIONS
 
